pub struct ArkUIInputEvent {
pub event_type: UIInputEvent,
pub action: UIInputAction,
pub source_type: UIInputSourceType,
pub tool_type: UIInputToolType,
/* private fields */
}Expand description
Wrapper for ArkUI_UIInputEvent.
Fields
event_type: UIInputEventaction: UIInputActionsource_type: UIInputSourceTypetool_type: UIInputToolTypeImplementations
Sourceimpl ArkUIInputEvent
impl ArkUIInputEvent
pub fn axis_vertical_value(&self) -> f64
pub fn axis_horizontal_value(&self) -> f64
pub fn axis_pinch_scale_value(&self) -> f64
Sourceimpl ArkUIInputEvent
impl ArkUIInputEvent
pub fn pointer_x(&self) -> f32
pub fn pointer_x_by_index(&self, pointer_index: u32) -> f32
pub fn pointer_y(&self) -> f32
pub fn pointer_y_by_index(&self, pointer_index: u32) -> f32
pub fn pointer_window_x(&self) -> f32
pub fn pointer_window_x_by_index(&self, pointer_index: u32) -> f32
pub fn pointer_window_y(&self) -> f32
pub fn pointer_window_y_by_index(&self, pointer_index: u32) -> f32
pub fn pointer_display_x(&self) -> f32
pub fn pointer_display_x_by_index(&self, pointer_index: u32) -> f32
pub fn pointer_display_y(&self) -> f32
pub fn pointer_display_y_by_index(&self, pointer_index: u32) -> f32
pub fn pointer_pressure(&self, pointer_index: u32) -> f32
pub fn pointer_tilt_x(&self, pointer_index: u32) -> f32
pub fn pointer_tilt_y(&self, pointer_index: u32) -> f32
pub fn pointer_touch_area_width(&self, pointer_index: u32) -> f32
pub fn pointer_touch_area_height(&self, pointer_index: u32) -> f32
pub fn pointer_history_size(&self) -> u32
pub fn pointer_history_event_time(&self, history_index: u32) -> i64
pub fn pointer_history_pointer_count(&self, history_index: u32) -> u32
pub fn pointer_history_pointer_id( &self, pointer_index: u32, history_index: u32, ) -> i32
pub fn pointer_history_x(&self, pointer_index: u32, history_index: u32) -> f32
pub fn pointer_history_y(&self, pointer_index: u32, history_index: u32) -> f32
pub fn pointer_history_window_x( &self, pointer_index: u32, history_index: u32, ) -> f32
pub fn pointer_history_window_y( &self, pointer_index: u32, history_index: u32, ) -> f32
pub fn pointer_history_display_x( &self, pointer_index: u32, history_index: u32, ) -> f32
pub fn pointer_history_display_y( &self, pointer_index: u32, history_index: u32, ) -> f32
pub fn pointer_history_pressure( &self, pointer_index: u32, history_index: u32, ) -> f32
pub fn pointer_history_tilt_x( &self, pointer_index: u32, history_index: u32, ) -> f32
pub fn pointer_history_tilt_y( &self, pointer_index: u32, history_index: u32, ) -> f32
pub fn pointer_history_touch_area_width( &self, pointer_index: u32, history_index: u32, ) -> f32
pub fn pointer_history_touch_area_height( &self, pointer_index: u32, history_index: u32, ) -> f32
pub fn pointer_set_intercept_hit_test_mode( &self, mode: HitTest, ) -> Result<(), ArkUIInputError>
pub fn mouse_action(&self) -> UIMouseEventAction
pub fn pointer_set_stop_propagation( &self, stop_propagation: bool, ) -> Result<(), ArkUIInputError>
Sourceimpl ArkUIInputEvent
impl ArkUIInputEvent
pub fn raw(&self) -> *const ArkUI_UIInputEvent
pub fn from_raw(event: *const ArkUI_UIInputEvent) -> Self
pub fn event_time(&self) -> i64
Sourcepub fn pointer_count(&self) -> u32
pub fn pointer_count(&self) -> u32
Get the number of contact points from a pointer event (such as a touch, mouse, or axis event).
Sourcepub fn pointer_id(&self, pointer_index: u32) -> i32
pub fn pointer_id(&self, pointer_index: u32) -> i32
Get the unique ID of a contact point from a pointer event (such as a touch, mouse, or axis event).
Sourcepub fn get_scroll_delta_y(&self) -> Result<f64, ArkUIInputError>
pub fn get_scroll_delta_y(&self) -> Result<f64, ArkUIInputError>
Get the vertical scroll delta of an axis event. Only works for touch board and mouse wheel.
Sourcepub fn get_scroll_delta_x(&self) -> Result<f64, ArkUIInputError>
pub fn get_scroll_delta_x(&self) -> Result<f64, ArkUIInputError>
Get the horizontal scroll delta of an axis event. Only works for touch board.